%define debug_package %{nil}

%bcond_with bootstrap

Name:		freebasic
Summary:	Free BASIC language compiler
Version:	1.07.0
Release:	%mkrel 2
License:	GPLv2
Group:		Development/Other
URL:		http://freebasic.net
Source0:	https://download.sourceforge.net/fbc/FreeBASIC-%{version}-source.tar.xz
# Bootstrap sources can't be inside conditional
# Comment out if not bootstrap build
Source10:	https://github.com/freebasic/fbc/releases/download/%{version}/FreeBASIC-%{version}-source-bootstrap.tar.xz
Patch0:		freebasic-bootstrap.patch
Patch1:		freebasic-aarch64.patch
BuildRequires:	dos2unix
BuildRequires:	libgpm-devel
BuildRequires:	libtermcap-devel
%if %{without bootstrap}
BuildRequires:	freebasic
%else
BuildRequires:	dos2unix
%endif
BuildRequires:	pkgconfig(xpm)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xext)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(xrandr)
BuildRequires:	pkgconfig(libffi)
BuildRequires:	gcc
BuildRequires:	pkgconfig(zlib)
Provides:	FreeBASIC = %{version}
Provides:	fbc = %{version}

%description
Open-source, free, multi-platform BASIC compiler, with syntax similar
MS-QuickBASIC (including the GFX statements), that adds new features
such as pointers, unsigned data types, inline assembly, a pre-processor
and many others.

%prep
%setup -q %{?with_bootstrap:-T -b10} -n FreeBASIC-%{version}-source%{?with_bootstrap:-bootstrap}
%autopatch -p1

%build
%set_build_flags

%if %{with bootstrap}
# create missing bootstrap source dir
%ifnarch %{ix86} x86_64
cp -a bootstrap/linux-x86_64 bootstrap/linux-%{_arch}
%endif

# we need to bootstrap fbc twice to get updated and working bootstrap sources
# modified bootstrap-dist target creates updated bootstrap sources
%make_build bootstrap V=1
%make_build bootstrap-dist

# remove binary used for bootstrapping sources update
make clean
%endif

%make_build \
  %{?with_bootstrap:bootstrap} \
  V=1

%install
mkdir -p %{buildroot}%{_prefix}

#Minimal installation
make install prefix=%{buildroot}%{_prefix}

#Man
mkdir -p %{buildroot}%{_mandir}/man1
cp -f ./doc/fbc.1 %{buildroot}%{_mandir}/man1/

#Examples
mkdir -p %{buildroot}%{_datadir}/freebasic
cp -rf ./examples %{buildroot}%{_datadir}/freebasic/

%files
%doc doc/GoRC.txt readme.txt
%{_prefix}/lib/freebasic
%{_includedir}/freebasic
%{_mandir}/man1/fbc.1.*
%{_bindir}/fbc
%{_datadir}/freebasic


%changelog
* Wed Mar 30 2022 umeabot <umeabot> 1.07.0-2.mga9
+ Revision: 1835272
- Mageia 9 Mass Rebuild

* Wed Feb 19 2020 pterjan <pterjan> 1.07.0-1.mga8
+ Revision: 1544474
- Update to 1.07.0

* Thu Feb 13 2020 umeabot <umeabot> 1.05.0-7.mga8
+ Revision: 1512327
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%setup_compile_flags

* Sun Sep 23 2018 umeabot <umeabot> 1.05.0-6.mga7
+ Revision: 1297761
- Mageia 7 Mass Rebuild

* Tue Aug 14 2018 wally <wally> 1.05.0-5.mga7
+ Revision: 1251501
- disable bootstrap for arm and aarch64

* Mon Aug 13 2018 wally <wally> 1.05.0-4.mga7
+ Revision: 1251425
- BR dos2unix

* Mon Aug 13 2018 wally <wally> 1.05.0-3.mga7
+ Revision: 1251421
- bootstrap also on arm

* Mon Aug 13 2018 wally <wally> 1.05.0-2.mga7
+ Revision: 1251417
- bootstrap build for aarch64

* Mon Mar 26 2018 kekepower <kekepower> 1.05.0-1.mga7
+ Revision: 1212717
- Update to version 1.05.0

* Sat Feb 20 2016 umeabot <umeabot> 1.04.0-2.mga6
+ Revision: 972458
- Mageia 6 Mass Rebuild

* Thu Nov 05 2015 alexl <alexl> 1.04.0-1.mga6
+ Revision: 898018
- version 1.04.0

* Wed Sep 09 2015 neoclust <neoclust> 1.02.1-2.mga6
+ Revision: 874921
- Fix build with new rpm ( empty debuginfo)

* Wed Jul 01 2015 alexl <alexl> 1.02.1-1.mga6
+ Revision: 849416
- add fbc to provides
- version 1.02.1

* Sat Oct 25 2014 alexl <alexl> 1.00.0-3.mga5
+ Revision: 793285
- disable bootstrap

* Sat Oct 25 2014 alexl <alexl> 1.00.0-2.mga5
+ Revision: 793280
- installed in /usr/lib for x86_64 (upstream bug #742)
- enabled bootstrap, because we have no x86_64 pkg in repo
- updated description
- version 1.00.0 with x86 and x86_64 support

* Thu Feb 06 2014 stormi <stormi> 0.90.1-3.mga5
+ Revision: 584804
- use version macro instead of specific version
- remove unwanted doc files

* Thu Feb 06 2014 wally <wally> 0.90.1-2.mga5
+ Revision: 584795
- disable bootstrap

* Thu Feb 06 2014 wally <wally> 0.90.1-1.mga5
+ Revision: 584779
- add bootstrap option to .spec
- clean .spec a bit
- imported package freebasic

